@@ -31,6 +31,7 @@
 #include <sys/types.h>
 #include <sys/socket.h>
 #include <netinet/in.h>
+#include <gtk/gtk.h>
 
 #include "vino-util.h"
 #include "vino-mdns.h"
@@ -183,7 +184,7 @@ vino_http_lookup_client_logo (void)
   icon_theme = gtk_icon_theme_get_default ();
 
   info = gtk_icon_theme_lookup_icon (icon_theme,
-				     "gnome-remote-desktop",
+				     "preferences-desktop-remote-desktop",
 				     ICON_SIZE_STANDARD,
 				     GTK_ICON_LOOKUP_NO_SVG);
   if (info)
@@ -584,7 +585,7 @@ static inline int
 start_probing_at (int rfb_port)
 {
   if (rfb_port >= VINO_RFB_MIN_PORT && rfb_port <= VINO_RFB_MAX_PORT)
-    return VINO_HTTP_MIN_PORT + (VINO_RFB_MIN_PORT - rfb_port);
+    return VINO_HTTP_MIN_PORT + (rfb_port - VINO_RFB_MIN_PORT);
 
   return VINO_HTTP_MIN_PORT;
 }
@@ -841,3 +842,9 @@ vino_http_remove_rfb_port (VinoHTTP *http,
       http->priv->rfb_ports = NULL;
     }
 }
+
+int
+vino_get_http_server_port ()
+{
+  return singleton_http->priv->http_port;
+}
