@@ -25,13 +25,12 @@
 
 #include <config.h>
 #include <libintl.h>
-#include <glib/gmacros.h>
+#include <glib.h>
+#include <glib/gi18n.h>
+#include <gtk/gtk.h>
 
 G_BEGIN_DECLS
 
-#define  _(x) dgettext (GETTEXT_PACKAGE, x)
-#define N_(x) (x)
-
 #define VINO_STOCK_ALLOW  "vino-allow"
 #define VINO_STOCK_REFUSE "vino-refuse"
 
@@ -45,7 +44,9 @@ typedef enum
   VINO_DEBUG_TLS     = 1 << 4,
   VINO_DEBUG_MDNS    = 1 << 5,
   VINO_DEBUG_PROMPT  = 1 << 6,
-  VINO_DEBUG_HTTP    = 1 << 7
+  VINO_DEBUG_HTTP    = 1 << 7,
+  VINO_DEBUG_DBUS    = 1 << 8,
+  VINO_DEBUG_UPNP    = 1 << 9
 } VinoDebugFlags;
 
 #ifdef G_ENABLE_DEBUG
@@ -80,9 +81,12 @@ void vino_setup_debug_flags (void);
 
 #endif /* G_ENABLE_DEBUG */
 
+void  vino_init_stock_items	(void);
+
+void  vino_util_show_error	(const gchar *title,
+				 const gchar *message,
+				 GtkWindow *parent);
 
-char *vino_base64_unencode  (const char *data);
-void  vino_init_stock_items (void);
 
 G_END_DECLS
 
